@@ -35,6 +35,7 @@ module.exports = {
   allowFreeURL: toBooleanConfig(process.env.CMD_ALLOW_FREEURL),
   requireFreeURLAuthentication: toBooleanConfig(process.env.CMD_REQUIRE_FREEURL_AUTHENTICATION),
   disableNoteCreation: toBooleanConfig(process.env.CMD_DISABLE_NOTE_CREATION),
+  enableUploads: process.env.CMD_ENABLE_UPLOADS,
   forbiddenNoteIDs: toArrayConfig(process.env.CMD_FORBIDDEN_NOTE_IDS),
   defaultPermission: process.env.CMD_DEFAULT_PERMISSION,
   dbURL: process.env.CMD_DB_URL,
@@ -114,7 +115,8 @@ module.exports = {
     clientSecret: process.env.CMD_OAUTH2_CLIENT_SECRET,
     scope: process.env.CMD_OAUTH2_SCOPE,
     rolesClaim: process.env.CMD_OAUTH2_ROLES_CLAIM,
-    accessRole: process.env.CMD_OAUTH2_ACCESS_ROLE
+    accessRole: process.env.CMD_OAUTH2_ACCESS_ROLE,
+    pkce: toBooleanConfig(process.env.CMD_OAUTH2_PKCE)
   },
   dropbox: {
     clientID: process.env.CMD_DROPBOX_CLIENTID,
@@ -146,6 +148,8 @@ module.exports = {
     issuer: process.env.CMD_SAML_ISSUER,
     identifierFormat: process.env.CMD_SAML_IDENTIFIERFORMAT,
     disableRequestedAuthnContext: toBooleanConfig(process.env.CMD_SAML_DISABLEREQUESTEDAUTHNCONTEXT),
+    wantAssertionsSigned: toBooleanConfig(process.env.CMD_SAML_WANT_ASSERTIONS_SIGNED),
+    wantAuthnResponseSigned: toBooleanConfig(process.env.CMD_SAML_WANT_AUTHN_RESPONSE_SIGNED),
     groupAttribute: process.env.CMD_SAML_GROUPATTRIBUTE,
     externalGroups: toArrayConfig(process.env.CMD_SAML_EXTERNALGROUPS, '|', []),
     requiredGroups: toArrayConfig(process.env.CMD_SAML_REQUIREDGROUPS, '|', []),
